@@ -1,7 +1,4 @@
-from __future__ import unicode_literals
-
-VERSION = (0, 8, 5)
-__version__ = '.'.join(str(v) for v in VERSION)
+__version__ = "0.18.0"
 
 
 def register(*args, **kwargs):
@@ -10,6 +7,7 @@ def register(*args, **kwargs):
     This is equivalent to just subclassing MPTTModel, but works for an already-created model.
     """
     from mptt.models import MPTTModelBase
+
     return MPTTModelBase.register(*args, **kwargs)
 
 
