@@ -1,13 +1,12 @@
 from django.contrib import admin
-
-from mptt.admin import MPTTModelAdmin, DraggableMPTTAdmin
-
 from myapp.models import Category, Person
 
+from mptt.admin import DraggableMPTTAdmin, MPTTModelAdmin
 
+
+@admin.register(Category)
 class CategoryAdmin(MPTTModelAdmin):
     pass
 
 
-admin.site.register(Category, CategoryAdmin)
 admin.site.register(Person, DraggableMPTTAdmin)
